@@ -2,12 +2,10 @@ package sqlite
 
 import (
 	"context"
+	"encoding/json"
 	"fmt"
-	"math/rand"
-	"os"
 	"testing"
 
-	"github.com/operator-framework/operator-lifecycle-manager/pkg/api/apis/operators/v1alpha1"
 	"github.com/stretchr/testify/require"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -16,12 +14,6 @@ import (
 	"github.com/operator-framework/operator-registry/pkg/registry"
 )
 
-var testScheme = runtime.NewScheme()
-
-func init() {
-	v1alpha1.AddToScheme(testScheme)
-}
-
 func TestAddPackageChannels(t *testing.T) {
 	type fields struct {
 		bundles []*registry.Bundle
@@ -135,14 +127,12 @@ func TestAddPackageChannels(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.description, func(t *testing.T) {
-			db := fmt.Sprintf("%d.db", rand.Int())
+			db, cleanup := CreateTestDb(t)
+			defer cleanup()
 			store, err := NewSQLLiteLoader(db)
 			require.NoError(t, err)
-			defer func() {
-				if err := os.Remove(db); err != nil {
-					t.Fatal(err)
-				}
-			}()
+			err = store.Migrate(context.TODO())
+			require.NoError(t, err)
 
 			for _, bundle := range tt.fields.bundles {
 				// Throw away any errors loading bundles (not testing this)
@@ -150,13 +140,12 @@ func TestAddPackageChannels(t *testing.T) {
 			}
 
 			for i, pkg := range tt.args.pkgs {
-				require.Equal(t, tt.expected.errs[i], store.AddPackageChannels(pkg))
+				errs := store.AddPackageChannels(pkg)
+				require.Equal(t, tt.expected.errs[i], errs, "expected %v, got %v", tt.expected.errs[i], errs)
 			}
 
 			// Ensure expected packages were loaded
-			querier, err := NewSQLLiteQuerier(db)
-			require.NoError(t, err)
-
+			querier := NewSQLLiteQuerierFromDb(db)
 			pkgs, err := querier.ListPackages(context.Background())
 			require.NoError(t, err)
 			require.ElementsMatch(t, tt.expected.pkgs, pkgs)
@@ -165,14 +154,14 @@ func TestAddPackageChannels(t *testing.T) {
 }
 
 func newUnstructuredCSV(t *testing.T, name, replaces string) *unstructured.Unstructured {
-	csv := &v1alpha1.ClusterServiceVersion{}
+	csv := &registry.ClusterServiceVersion{}
+	csv.TypeMeta.Kind = "ClusterServiceVersion"
 	csv.SetName(name)
-	csv.Spec.Replaces = replaces
+	csv.Spec = json.RawMessage(fmt.Sprintf(`{"replaces": "%s"}`, replaces))
 
-	out := &unstructured.Unstructured{}
-	require.NoError(t, testScheme.Convert(csv, out, nil))
-
-	return out
+	out, err := runtime.DefaultUnstructuredConverter.ToUnstructured(csv)
+	require.NoError(t, err)
+	return &unstructured.Unstructured{Object: out}
 }
 
 func newBundle(t *testing.T, name, pkgName, channelName string, objs ...*unstructured.Unstructured) *registry.Bundle {
